@@ -7,7 +7,7 @@ from laboro.error import LaboroError
 
 
 class Manager:
-  """The ``laboro.module.manager.Manager`` object manages all aspect of module handling such as loading and, registration,
+  """The ``laboro.module.manager.Manager`` object manages all aspect of module handling such as package installation, module loading and module registration.
   """
   modules = dict()
 
@@ -37,7 +37,7 @@ class Manager:
 
     Once registered the specified ``cls`` will be accessible through the ``modules`` attribute.
 
-    Registering a module is used to import external Laboro modules (search the documentation for 'external Laboro modules').
+    Registering a module is used to import external Laboro modules.
 
     To prevent abusive standard Python packages imports, module name defined by the ``module`` argument must match the following regular expression: ``^laboro_.*``.
 
@@ -48,14 +48,15 @@ class Manager:
     Raises:
       ``laboro.error.LaboroError``: When an ImportError occurred while attempting to register an unknown class or a class from an unknown module.
 
-    In the following example illustrate how to import the ``PgClient`` class from the ``laboro_database`` package.
+    In the following example illustrate how to import the ``PgClient`` class from the ``laboro_database.clients`` package.
 
     ..  code-block:: python
 
       from laboro.module.manager import Manager
 
       module_mgr = Manager()
-      module_mgr.register(cls="PgClient", module="laboro_database")
+      module_mgr.install_package(laboro_database)
+      module_mgr.register(cls="PgClient", module="laboro_database.clients")
 
     """
     if cls not in self.modules:
@@ -80,7 +81,7 @@ class Manager:
       module: A string specifying the module to retrieve the class from.
 
     Raises:
-      ``laboro.error.LaboroError``: When the specified module or class is unknown.
+      ``laboro.error.LaboroError``: When the specified module or class is unregistered.
     """
     try:
       return self.modules[module][cls]
