@@ -2,9 +2,9 @@ import re
 
 
 class Vault:
-  """The ``laboro.vault.Vault`` class manages sensible information that should not appear in log files.
+  """The ``laboro.vault.Vault`` class manages sensible informations that should not appear in log files.
 
-  **Note:** Even if data stored in Vault will not appear in log files, they are NOT encrypted in the memory and are still recoverable by object inspection and debugger tools."""
+  **Note:** Even if they will not appear in log files or `stdout`, **data stored in Vault are NOT encrypted** in the memory and are still recoverable by object inspection and debugger tools."""
 
   @property
   def protected(self):
